module Ucb
  module Hcm
    module Configuration
      VALID_CONNECTION_KEYS = [:endpoint, :user_agent, :method].freeze
      VALID_OPTIONS_KEYS    = [:app_id, :app_key, :format].freeze
      VALID_CONFIG_KEYS     = VALID_CONNECTION_KEYS + VALID_OPTIONS_KEYS

      DEFAULT_ENDPOINT    = 'https://apis.berkeley.edu/uat/hr/v3'
      DEFAULT_METHOD      = :get
      DEFAULT_USER_AGENT  = "Ucb::Hcm API Ruby Gem #{Ucb::Hcm::VERSION}".freeze

      DEFAULT_APP_ID       = nil
      DEFAULT_APP_KEY      = nil
      DEFAULT_FORMAT       = :json

      # Build accessor methods for every config options so we can do this, for example:
      #   Awesome.format = :xml
      attr_accessor(*VALID_CONFIG_KEYS)

      # Make sure we have the default values set when we get 'extended'
      def self.extended(base)
        base.reset
      end

      def reset
        self.endpoint   = DEFAULT_ENDPOINT
        self.method     = DEFAULT_METHOD
        self.user_agent = DEFAULT_USER_AGENT

        self.app_id     = DEFAULT_APP_ID
        self.app_key    = DEFAULT_APP_KEY
        self.format     = DEFAULT_FORMAT
      end

      def options
        Hash[ * VALID_CONFIG_KEYS.map { |key| [key, send(key)] }.flatten ]
      end

      def configure
        yield self
      end

    end
  end
end
