require "hashie"
require_relative "data_fetcher"

module Ucb
  module Hcm
    class Response
      extend Forwardable

      attr_reader :raw_response

      def_delegators :raw_response, :code

      def initialize(raw_response)
        @raw_response = raw_response
      end

      def success?
        code == 200
      end

      def raw
        raw_response
      end

      def all
        raw_response&.fetch("response", []) || []
      end

      def all_fetchers
        all.map { |item| Ucb::Hcm::DataFetcher.new(item) }
      end

      def each
        all.each { |item| yield item }
      end

      def each_fetcher
        all.each { |item| yield Ucb::Hcm::DataFetcher.new(item) }
      end

      ##############################
      # deprecations

      def response
        warn "Ucb::Hcm#response is deprecated and will be removed in future versions - use #raw_response instead"
        raw_response
      end

      def data
        warn "Ucb::Hcm#data is deprecated and will be removed in future versions - use #raw_response['response'] instead"
        if raw_response["response"]&.count == 1
          raw_response["response"]&.first
        else
          raw_response["response"]
        end
      end

    end
  end
end
